<?php
/**
 * hostingo functions and definitions
 *
 * Set up the theme and provides some helper functions, which are used in the
 * theme as custom template tags. Others are attached to action and filter
 * hooks in WordPress to change core functionality.
 *
 * When using a child theme you can override certain functions (those wrapped
 * in a function_exists() call) by defining them first in your child theme's
 * functions.php file. The child theme's functions.php file is included before
 * the parent theme's file, so the child theme functions would be used.
 *
 * @link https://codex.wordpress.org/Theme_Development
 * @link https://developer.wordpress.org/themes/advanced-topics/child-themes/
 *
 * Functions that are not pluggable (not wrapped in function_exists()) are
 * instead attached to a filter or action hook.
 *
 * For more information on hooks, actions, and filters,
 * {@link https://codex.wordpress.org/Plugin_API}
 *
 * @package WordPress
 * @subpackage hostingo
 * @since hostingo 1.0
 */
namespace peaceful\hostingo;
class Init
{
	public function __construct (){
		$this->constants();
		$this->version_compare();
		$this->load_dependencies();
	}
	 public function load_dependencies()
	 {
	 	
	 	require_once HOSTINGO_DIR . '/inc/theme-setup.php';
        require_once HOSTINGO_DIR . '/inc/theme-helper.php';
        require HOSTINGO_ADMIN_DIR . '/classes/autoload.php';
	 	require_once HOSTINGO_DIR . '/inc/customizer/init.php';
	 }
	 private function constants()
	 {
	 	define('HOSTINGO_DIR', get_template_directory());                  
		
		define('HOSTINGO_URI', get_template_directory_uri());  
		define('HOSTINGO_ADMIN', admin_url());   
		define('HOSTINGO_ADMIN_DIR', get_template_directory() .  '/admin/');  
		define('HOSTINGO_ASSETS_URI', HOSTINGO_URI . '/assets/'); 
	 }
	 private function version_compare()
	 {
	 	if ( version_compare( $GLOBALS['wp_version'], '4.4-alpha', '<' ) ) {
			require HOSTINGO_DIR . '/inc/back-compat.php';
		}
	 }
}
new Init;
